==> jc-1.4.0.tar.gz: soot/util/EscapedWriter.h <==
// public class soot.util.EscapedWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ddd7aa1875070527 soot_util_EscapedWriter

// header file dependencies
// @dep_header java_io_FilterWriter

#include "java/io/FilterWriter.h"

#ifndef _JC_soot_util_EscapedWriter_H_
#define _JC_soot_util_EscapedWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_soot_util_EscapedWriter$sub_refs	_jc_soot_util_EscapedWriter$sub_refs;
typedef struct _jc_soot_util_EscapedWriter$sub_nonrefs	_jc_soot_util_EscapedWriter$sub_nonrefs;
typedef struct _jc_soot_util_EscapedWriter$refs	_jc_soot_util_EscapedWriter$refs;
typedef struct _jc_soot_util_EscapedWriter$nonrefs	_jc_soot_util_EscapedWriter$nonrefs;
typedef struct _jc_soot_util_EscapedWriter$object	_jc_soot_util_EscapedWriter$object;

typedef const struct _jc_soot_util_EscapedWriter$vmethods	_jc_soot_util_EscapedWriter$vmethods;
typedef const struct _jc_soot_util_EscapedWriter$vtable	_jc_soot_util_EscapedWriter$vtable;
typedef const struct _jc_soot_util_EscapedWriter$vtype	_jc_soot_util_EscapedWriter$vtype;

// Constructors
extern void _jc_soot_util_EscapedWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_io_Writer$object *);

// Virtual methods
extern void _jc_soot_util_EscapedWriter$method$print$47ddf1496330d0de(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint);
extern void _jc_soot_util_EscapedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint);
extern void _jc_soot_util_EscapedWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_util_EscapedWriter$method_info$print$47ddf1496330d0de;
extern _jc_method _jc_soot_util_EscapedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_soot_util_EscapedWriter$method_info$write$4cff879bd9d86786;

// Virtual methods structure
struct _jc_soot_util_EscapedWriter$vmethods {
	void	(*print$47ddf1496330d0de)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint);
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
};

// Vtable
struct _jc_soot_util_EscapedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
	_jc_soot_util_EscapedWriter$vmethods	soot_util_EscapedWriter;
};

// Vtype
struct _jc_soot_util_EscapedWriter$vtype {
	_jc_type			type;
	_jc_soot_util_EscapedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_EscapedWriter$sub_refs {
	struct _jc_java_lang_String$object	*lineSeparator;
	struct _jc_java_lang_StringBuffer$object	*mini;
};

// Reference instance fields (object)
struct _jc_soot_util_EscapedWriter$refs {
    _jc_soot_util_EscapedWriter$sub_refs	soot_util_EscapedWriter;
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_EscapedWriter$sub_nonrefs {
	jint	cr;
	jint	lf;
};

// Non-reference instance fields (object)
struct _jc_soot_util_EscapedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
    _jc_soot_util_EscapedWriter$sub_nonrefs	soot_util_EscapedWriter;
};

// Object instance structure
struct _jc_soot_util_EscapedWriter$object {
	_jc_soot_util_EscapedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_EscapedWriter$vtype	*vtype;
	_jc_soot_util_EscapedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_EscapedWriter$vtype _jc_soot_util_EscapedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_EscapedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_EscapedWriter$class_object;

#endif	/* _JC_soot_util_EscapedWriter_H_ */

==> jc-1.4.6.tar.gz: soot/util/EscapedWriter.h <==
// public class soot.util.EscapedWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ddd7aa1875070527 soot_util_EscapedWriter

// header file dependencies
// @dep_header java_io_FilterWriter

#include "java/io/FilterWriter.h"

#ifndef _JC_soot_util_EscapedWriter_H_
#define _JC_soot_util_EscapedWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_soot_util_EscapedWriter$sub_refs	_jc_soot_util_EscapedWriter$sub_refs;
typedef struct _jc_soot_util_EscapedWriter$sub_nonrefs	_jc_soot_util_EscapedWriter$sub_nonrefs;
typedef struct _jc_soot_util_EscapedWriter$refs	_jc_soot_util_EscapedWriter$refs;
typedef struct _jc_soot_util_EscapedWriter$nonrefs	_jc_soot_util_EscapedWriter$nonrefs;
typedef struct _jc_soot_util_EscapedWriter$object	_jc_soot_util_EscapedWriter$object;

typedef const struct _jc_soot_util_EscapedWriter$vmethods	_jc_soot_util_EscapedWriter$vmethods;
typedef const struct _jc_soot_util_EscapedWriter$vtable	_jc_soot_util_EscapedWriter$vtable;
typedef const struct _jc_soot_util_EscapedWriter$vtype	_jc_soot_util_EscapedWriter$vtype;

// Constructors
extern void _jc_soot_util_EscapedWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_EscapedWriter$method$print$47ddf1496330d0de(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_util_EscapedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_util_EscapedWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_EscapedWriter$method_info$print$47ddf1496330d0de;
extern _jc_method _jc_soot_util_EscapedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_soot_util_EscapedWriter$method_info$write$4cff879bd9d86786;

// Virtual methods structure
struct _jc_soot_util_EscapedWriter$vmethods {
	void	(*print$47ddf1496330d0de)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_soot_util_EscapedWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_EscapedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
	_jc_soot_util_EscapedWriter$vmethods	soot_util_EscapedWriter;
};

// Vtype
struct _jc_soot_util_EscapedWriter$vtype {
	_jc_type			type;
	_jc_soot_util_EscapedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_EscapedWriter$sub_refs {
	struct _jc_java_lang_String$object	*lineSeparator;
	struct _jc_java_lang_StringBuffer$object	*mini;
};

// Reference instance fields (object)
struct _jc_soot_util_EscapedWriter$refs {
    _jc_soot_util_EscapedWriter$sub_refs	soot_util_EscapedWriter;
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_EscapedWriter$sub_nonrefs {
	jint	cr;
	jint	lf;
};

// Non-reference instance fields (object)
struct _jc_soot_util_EscapedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
    _jc_soot_util_EscapedWriter$sub_nonrefs	soot_util_EscapedWriter;
};

// Object instance structure
struct _jc_soot_util_EscapedWriter$object {
	_jc_soot_util_EscapedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_EscapedWriter$vtype	*vtype;
	_jc_soot_util_EscapedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_EscapedWriter$vtype _jc_soot_util_EscapedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_EscapedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_EscapedWriter$class_object;

#endif	/* _JC_soot_util_EscapedWriter_H_ */
